$set 3 #Configmenu

$ #ConfigOptions
# Ayarlar
$ #FocusModel
# Foksleme
$ #WindowPlacement
# Pencere yerleimi
$ #ImageDithering
# Resim oluturmas
$ #OpaqueMove
# Ekran ierikli ta
$ #FullMax
# Tam ekranla, vallahi
$ #FocusNew
# Yeni pencereleri foksle
$ #FocusLast
# Masastndeki son pencereyi foksle
$ #ClickToFocus
# Tklayarak foksle
$ #SloppyFocus
# Ar foksle
$ #AutoRaise
# Otomatikman ykselt
$ #SmartRows
# Akll yerleim( Sralar )
$ #SmartCols
# Akll yerleim( Stunlar )
$ #Cascade
# Cascade Placement
$ #LeftRight
# Soldan saa
$ #RightLeft
# Sadan sola
$ #TopBottom
# stten aaa
$ #BottomTop
# Alttan ste
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
